/* 
 * Motif
 *
 * Copyright (c) 1987-2012, The Open Group. All rights reserved.
 *
 * These libraries and programs are free software; you can
 * redistribute them and/or modify them under the terms of the GNU
 * Lesser General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * These libraries and programs are distributed in the hope that
 * they will be useful, but WITHOUT ANY WARRANTY; without even the
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with these librararies and programs; if not, write
 * to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
*/ 
#ifndef _XmTransltnsP_h
#define _XmTransltnsP_h

#include <X11/Intrinsic.h>	/* for externalref */

#ifdef __cplusplus
extern "C" {
#endif


#ifndef _XmConst
#define _XmConst
#endif


externalref _XmConst char _XmArrowB_defaultTranslations[];
externalref _XmConst char _XmBulletinB_defaultTranslations[];
externalref _XmConst char _XmCascadeB_menubar_events[];
externalref _XmConst char _XmCascadeB_p_events[];
externalref _XmConst char _XmComboBox_defaultTranslations[];
externalref _XmConst char _XmComboBox_defaultAccelerators[];
externalref _XmConst char _XmComboBox_dropDownComboBoxAccelerators[];
externalref _XmConst char _XmComboBox_dropDownListTranslations[];
externalref _XmConst char _XmComboBox_textFocusTranslations[];
externalref _XmConst char _XmContainer_defaultTranslations[];
externalref _XmConst char _XmContainer_traversalTranslations[];
externalref _XmConst char _XmDisplay_baseTranslations[];
externalref _XmConst char _XmDragC_defaultTranslations[];
externalref _XmConst char _XmDrawingA_defaultTranslations[];
externalref _XmConst char _XmDrawingA_traversalTranslations[];
externalref _XmConst char _XmDrawnB_defaultTranslations[];
externalref _XmConst char _XmDrawnB_menuTranslations[];
externalref _XmConst char _XmFrame_defaultTranslations[];
externalref _XmConst char _XmGrabShell_translations [];
externalref _XmConst char _XmLabel_defaultTranslations[];
externalref _XmConst char _XmLabel_menuTranslations[];
externalref _XmConst char _XmLabel_menu_traversal_events[];
externalref _XmConst char _XmList_ListXlations1[];
externalref _XmConst char _XmList_ListXlations2[];
externalref _XmConst char _XmManager_managerTraversalTranslations[];
externalref _XmConst char _XmManager_defaultTranslations[];
externalref _XmConst char _XmNotebook_manager_translations[];
externalref _XmConst char _XmNotebook_TabAccelerators[];
externalref _XmConst char _XmMenuShell_translations [];
externalref _XmConst char _XmPrimitive_defaultTranslations[];
externalref _XmConst char _XmPushB_defaultTranslations[];
externalref _XmConst char _XmPushB_menuTranslations[];
externalref _XmConst char _XmRowColumn_menu_traversal_table[];
externalref _XmConst char _XmRowColumn_bar_table[];
externalref _XmConst char _XmRowColumn_option_table[];
externalref _XmConst char _XmRowColumn_menu_table[];
externalref _XmConst char _XmSash_defTranslations[];
externalref _XmConst char _XmScrollBar_defaultTranslations[];
externalref _XmConst char _XmScrolledW_ScrolledWindowXlations[];
externalref _XmConst char _XmClipWindowTranslationTable[];
externalref _XmConst char _XmScrolledW_WorkWindowTranslationTable[];
externalref _XmConst char _XmSelectioB_defaultTextAccelerators[];
externalref _XmConst char _XmSpinB_defaultTranslations[];
externalref _XmConst char _XmSpinB_defaultAccelerators[];
externalref _XmConst char _XmTearOffB_overrideTranslations[];
externalref _XmConst char _XmTextF_EventBindings1[];
externalref _XmConst char _XmTextF_EventBindings2[]; 
externalref _XmConst char _XmTextF_EventBindings3[];
externalref _XmConst char _XmDataF_EventBindings1[];
externalref _XmConst char _XmDataF_EventBindings2[];
externalref _XmConst char _XmDataF_EventBindings3[];
externalref _XmConst char _XmDataF_EventBindings4[];
externalref _XmConst char _XmTextIn_XmTextEventBindings1[];
externalref _XmConst char _XmTextIn_XmTextEventBindings2[];
externalref _XmConst char _XmTextIn_XmTextEventBindings3[];
externalref _XmConst char _XmTextIn_XmTextVEventBindings[];
externalref _XmConst char _XmToggleB_defaultTranslations[];
externalref _XmConst char _XmToggleB_menuTranslations[];
externalref _XmConst char _XmVirtKeys_fallbackBindingString[];

/*
 * The following keybindings have been "grandfathered" 
 * for backward compatablility.
 */
externalref _XmConst char _XmVirtKeys_acornFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_apolloFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_dgFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_decFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_dblclkFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_hpFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_ibmFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_ingrFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_megatekFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_motorolaFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_sgiFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_siemensWx200FallbackBindingString[];
externalref _XmConst char _XmVirtKeys_siemens9733FallbackBindingString[];
externalref _XmConst char _XmVirtKeys_sunFallbackBindingString[];
externalref _XmConst char _XmVirtKeys_tekFallbackBindingString[];

#ifdef __cplusplus
}  /* Close scope of 'extern "C"' declaration which encloses file. */
#endif

#endif /* _XmTransltnsP_h */
/* DON'T ADD ANYTHING AFTER THIS #endif */
